<?php

/**
* Register our settings section
*
* @return array
*/
function edds_settings_section( $sections ) {
	$sections['edd-stripe'] = __( 'Stripe', 'easy-digital-downloads' );

	return $sections;
}
add_filter( 'edd_settings_sections_gateways', 'edds_settings_section' );

/**
 * Register the gateway settings
 *
 * @access      public
 * @since       1.0
 * @return      array
 */
function edds_add_settings( $settings ) {
	// Output a placeholder setting to help promote Stripe
	// for non-Pro installs that do not meet PHP requirements.
	if (
		false === edds_has_met_requirements( 'php' ) &&
		false === edds_is_pro()
	) {
		return array_merge(
			$settings,
			array(
				'edd-stripe' => array(
					'edds-requirements-not-met' => array(
						'id'    => 'edds-requirements-not-met',
						'name'  => __( 'Unmet Requirements', 'easy-digital-downloads' ),
						'type'  => 'stripe_requirements_not_met',
						'class' => 'edds-requirements-not-met',
					),
				),
			)
		);
	}

	$stripe_settings = array(
		'stripe_connect_button' => array(
			'id' => 'stripe_connect_button',
			'name' => __( 'Connection Status', 'easy-digital-downloads' ),
			'desc' => edds_stripe_connect_setting_field(),
			'type' => 'descriptive_text',
			'class' => 'edd-stripe-connect-row',
		),
		'test_publishable_key'  => array(
			'id'   => 'test_publishable_key',
			'name'  => __( 'Test Publishable Key', 'easy-digital-downloads' ),
			'desc'  => __( 'Enter your test publishable key, found in your Stripe Account Settings', 'easy-digital-downloads' ),
			'type'  => 'text',
			'size'  => 'regular',
			'class' => 'edd-hidden edds-api-key-row',
		),
		'test_secret_key' => array(
			'id'   => 'test_secret_key',
			'name'  => __( 'Test Secret Key', 'easy-digital-downloads' ),
			'desc'  => __( 'Enter your test secret key, found in your Stripe Account Settings', 'easy-digital-downloads' ),
			'type'  => 'text',
			'size'  => 'regular',
			'class' => 'edd-hidden edds-api-key-row',
		),
		'live_publishable_key' => array(
			'id'   => 'live_publishable_key',
			'name'  => __( 'Live Publishable Key', 'easy-digital-downloads' ),
			'desc'  => __( 'Enter your live publishable key, found in your Stripe Account Settings', 'easy-digital-downloads' ),
			'type'  => 'text',
			'size'  => 'regular',
			'class' => 'edd-hidden edds-api-key-row',
		),
		'live_secret_key' => array(
			'id'   => 'live_secret_key',
			'name'  => __( 'Live Secret Key', 'easy-digital-downloads' ),
			'desc'  => __( 'Enter your live secret key, found in your Stripe Account Settings', 'easy-digital-downloads' ),
			'type'  => 'text',
			'size'  => 'regular',
			'class' => 'edd-hidden edds-api-key-row',
		),
		'stripe_webhook_description' => array(
			'id'    => 'stripe_webhook_description',
			'type'  => 'descriptive_text',
			'name'  => __( 'Webhooks', 'easy-digital-downloads' ),
			'desc'  =>
			'<p>' . sprintf(
				/* translators: %1$s Opening anchor tag, do not translate. %2$s Closing anchor tag, do not translate. */
				__( 'In order for Stripe to function completely, you must configure your Stripe webhooks. Visit your %1$saccount dashboard%2$s to configure them. Please add a webhook endpoint for the URL below.', 'easy-digital-downloads' ),
				'<a href="https://dashboard.stripe.com/account/webhooks" target="_blank" rel="noopener noreferrer">',
				'</a>'
			) . '</p>' .
			'<p><strong>' . sprintf(
				/* translators: %s Webhook URL. Do not translate. */
				__( 'Webhook URL: %s', 'easy-digital-downloads' ),
				home_url( 'index.php?edd-listener=stripe' )
			) . '</strong></p>' .
			'<p>' . sprintf(
				/* translators: %1$s Opening anchor tag, do not translate. %2$s Closing anchor tag, do not translate. */
				__( 'See our %1$sdocumentation%2$s for more information.', 'easy-digital-downloads' ),
				'<a href="' . esc_url( edds_documentation_route( 'stripe-webhooks' ) ) . '" target="_blank" rel="noopener noreferrer">',
				'</a>'
			) . '</p>'
		),
		'stripe_billing_fields' => array(
			'id'    => 'stripe_billing_fields',
			'name'  => __( 'Billing Address Display', 'easy-digital-downloads' ),
			'desc'  => __( 'Select how you would like to display the billing address fields on the checkout form. <p><strong>Notes</strong>:</p><p>If taxes are enabled, this option cannot be changed from "Full address".</p><p>If set to "No address fields", you <strong>must</strong> disable "zip code verification" in your Stripe account.</p>', 'easy-digital-downloads' ),
			'type'  => 'select',
			'options' => array(
				'full'        => __( 'Full address', 'easy-digital-downloads' ),
				'zip_country' => __( 'Zip / Postal Code and Country only', 'easy-digital-downloads' ),
				'none'        => __( 'No address fields', 'easy-digital-downloads' )
			),
			'std'   => 'full'
		),
 		'stripe_statement_descriptor' => array(
 			'id'   => 'stripe_statement_descriptor',
 			'name' => __( 'Statement Descriptor', 'easy-digital-downloads' ),
 			'desc' => __( 'Choose how charges will appear on customer\'s credit card statements. <em>Max 22 characters</em>', 'easy-digital-downloads' ),
 			'type' => 'text',
 		),
 		'stripe_use_existing_cards' => array(
			'id'   => 'stripe_use_existing_cards',
			'name' => __( 'Show Previously Used Cards', 'easy-digital-downloads' ),
			'desc' => __( 'Provides logged in customers with a list of previous used payment methods for faster checkout.', 'easy-digital-downloads' ),
			'type' => 'checkbox'
		),
		'stripe_allow_prepaid' => array(
			'id'    => 'stripe_allow_prepaid',
			'name'  => __( 'Prepaid Cards', 'easy-digital-downloads' ),
			'desc'  => __( 'Allow prepaid cards as valid payment method.', 'easy-digital-downloads' ),
			'type'  => 'checkbox',
		),
		'stripe_split_payment_fields' => array(
			'id'   => 'stripe_split_payment_fields',
			'name'  => __( 'Split Credit Card Form', 'easy-digital-downloads' ),
			'desc'  => __( 'Use separate card number, expiration, and CVC fields in payment forms.', 'easy-digital-downloads' ),
			'type'  => 'checkbox',
		),
		'stripe_restrict_assets' => array(
			'id' => 'stripe_restrict_assets',
			'name' => ( __( 'Restrict Stripe Assets', 'easy-digital-downloads' ) ),
			'desc' => ( __( 'Only load Stripe.com hosted assets on pages that specifically utilize Stripe functionality.', 'easy-digital-downloads' ) ),
			'type' => 'checkbox',
			'tooltip_title' => __( 'Loading Javascript from Stripe', 'easy-digital-downloads' ),
			'tooltip_desc' => __( 'Stripe advises that their Javascript library be loaded on every page to take advantage of their advanced fraud detection rules. If you are not concerned with this, enable this setting to only load the Javascript when necessary. Read more about Stripe\'s recommended setup here: https://stripe.com/docs/web/setup.', 'easy-digital-downloads' ),
		)
	);

	if ( edd_get_option( 'stripe_checkout' ) ) {
		$stripe_settings['stripe_checkout'] = array(
			'id'    => 'stripe_checkout',
			'name'  => '<strong>' . __( 'Stripe Checkout', 'easy-digital-downloads' ) . '</strong>',
			'type'  => 'stripe_checkout_notice',
			'desc'  => wp_kses(
				sprintf(
					/* translators: %1$s Opening anchor tag, do not translate. %2$s Closing anchor tag, do not translate. */
					esc_html__( 'To ensure your website is compliant with the new %1$sStrong Customer Authentication%2$s (SCA) regulations, the legacy Stripe Checkout modal is no longer supported. Payments are still securely accepted through through Stripe on the standard Easy Digital Downloads checkout page. "Buy Now" buttons will also automatically redirect to the standard checkout page.', 'easy-digital-downloads' ),
					'<a href="https://stripe.com/en-ca/guides/strong-customer-authentication" target="_blank" rel="noopener noreferrer">',
					'</a>'
				),
				array(
					'a' => array(
						'href'   => true,
						'rel'    => true,
						'target' => true,
					)
				)
			),
		);
	}

	if ( version_compare( EDD_VERSION, 2.5, '>=' ) ) {
		$stripe_settings = array( 'edd-stripe' => $stripe_settings );

		// Set up the new setting field for the Test Mode toggle notice
		$notice = array(
			'stripe_connect_test_mode_toggle_notice' => array(
				'id' => 'stripe_connect_test_mode_toggle_notice',
				'desc' => '<p>' . __( 'You have disabled the "Test Mode" option. Once you have saved your changes, please verify your Stripe connection, especially if you have not previously connected in with "Test Mode" disabled.', 'easy-digital-downloads' ) . '</p>',
				'type' => 'stripe_connect_notice',
				'field_class' => 'edd-hidden',
			)
		);

		// Insert the new setting after the Test Mode checkbox
		$position = array_search( 'test_mode', array_keys( $settings['main'] ), true );
		$settings = array_merge(
			array_slice( $settings['main'], $position, 1, true ),
			$notice,
			$settings
		);
	}

	return array_merge( $settings, $stripe_settings );
}
add_filter( 'edd_settings_gateways', 'edds_add_settings' );

/**
 * Force full billing address display when taxes are enabled
 *
 * @access      public
 * @since       2.5
 * @return      string
 */
function edd_stripe_sanitize_stripe_billing_fields_save( $value, $key ) {

	if( 'stripe_billing_fields' == $key && edd_use_taxes() ) {

		$value = 'full';

	}

	return $value;

}
add_filter( 'edd_settings_sanitize_select', 'edd_stripe_sanitize_stripe_billing_fields_save', 10, 2 );

/**
 * Filter the output of the statement descriptor option to add a max length to the text string
 *
 * @since 2.6
 * @param $html string The full html for the setting output
 * @param $args array  The original arguments passed in to output the html
 *
 * @return string
 */
function edd_stripe_max_length_statement_descriptor( $html, $args ) {
	if ( 'stripe_statement_descriptor' !== $args['id'] ) {
		return $html;
	}

	$html = str_replace( '<input type="text"', '<input type="text" maxlength="22"', $html );

	return $html;
}
add_filter( 'edd_after_setting_output', 'edd_stripe_max_length_statement_descriptor', 10, 2 );

/**
 * Callback for the stripe_connect_notice field type.
 *
 * @since 2.6.14
 *
 * @param array $args The setting field arguments.
 */
function edd_stripe_connect_notice_callback( $args ) {

	$value = isset( $args['desc'] ) ? $args['desc'] : '';

	$class = edd_sanitize_html_class( $args['field_class'] );

	?>
	<div class="<?php echo esc_attr( $class ); ?>" id="edd_settings[<?php echo edd_sanitize_key( $args['id'] ); ?>]">
		<?php echo wp_kses_post( $value ); ?>
	</div>
	<?php
}

/**
 * Callback for the stripe_checkout_notice field type.
 *
 * @since 2.7.0
 *
 * @param array $args The setting field arguments
 */
function edd_stripe_checkout_notice_callback( $args ) {
	$value = isset( $args['desc'] ) ? $args['desc'] : '';

	$html = '<div class="notice notice-warning inline' . edd_sanitize_html_class( $args['field_class'] ) . '" id="edd_settings[' . edd_sanitize_key( $args['id'] ) . ']">' . wpautop( $value ) . '</div>';

	echo $html;
}

/**
 * Outputs information when Stripe has been activated but application requirements are not met.
 *
 * @since 2.8.1
 */
function edd_stripe_requirements_not_met_callback() {
	$required_version = 5.6;
	$current_version  = phpversion();

	echo '<div class="notice inline notice-warning">';
	echo '<p>';
	echo wp_kses(
		sprintf(
			/* translators: %1$s Future PHP version requirement. %2$s Current PHP version. %3$s Opening strong tag, do not translate. %4$s Closing strong tag, do not translate. */
			__(
				'Processing credit cards with Stripe requires PHP version %1$s or higher. It looks like you\'re using version %2$s, which means you will need to %3$supgrade your version of PHP before acceping credit card payments%4$s.',
				'easy-digital-downloads'
			),
			'<code>' . $required_version . '</code>',
			'<code>' . $current_version . '</code>',
			'<strong>',
			'</strong>'
		),
		array(
			'code'   => true,
			'strong' => true
		)
	);
	echo '</p>';
	echo '<p>';

	echo '<strong>';
	esc_html_e( 'Need help upgrading? Ask your web host!', 'easy-digital-downloads' );
	echo '</strong><br />';

	echo wp_kses(
		sprintf(
			/* translators: %1$s Opening anchor tag, do not translate. %2$s Closing anchor tag, do not translate. */
			__(
				'Many web hosts can give you instructions on how/where to upgrade your version of PHP through their control panel, or may even be able to do it for you. If you need to change hosts, please see %1$sour hosting recommendations%2$s.',
				'easy-digital-downloads'
			),
			'<a href="https://easydigitaldownloads.com/recommended-wordpress-hosting/" target="_blank" rel="noopener noreferrer">',
			'</a>'
		),
		array(
			'a' => array(
				'href'   => true,
				'target' => true,
				'rel'    => true,
			),
		)
	);
	echo '</p>';
	echo '</div>';
}

/**
 * Adds a notice to the "Payment Gateways" selector if Stripe has been activated but does
 * not meet application requirements.
 *
 * @since 2.8.1
 *
 * @param string $html Setting HTML.
 * @param array $args Setting arguments.
 * @return string
 */
function edds_payment_gateways_notice( $html, $args ) {
	if ( 'gateways' !== $args['id'] ) {
		return $html;
	}

	if (
		true === edds_is_pro() ||
		true === edds_has_met_requirements( 'php' )
	) {
		return $html;
	}

	$required_version = 5.6;
	$current_version  = phpversion();

	$html .= '<div id="edds-payment-gateways-stripe-unmet-requirements" class="notice inline notice-info"><p>' .
		wp_kses(
			sprintf(
				/* translators: %1$s PHP version requirement. %2$s Current PHP version. %3$s Opening strong tag, do not translate. %4$s Closing strong tag, do not translate. */
				__(
					'Processing credit cards with Stripe requires PHP version %1$s or higher. It looks like you\'re using version %2$s, which means you will need to %3$supgrade your version of PHP before acceping credit card payments%4$s.',
					'easy-digital-downloads'
				),
				'<code>' . $required_version . '</code>',
				'<code>' . $current_version . '</code>',
				'<strong>',
				'</strong>'
			),
			array(
				'code'   => true,
				'strong' => true
			)
		) .
	'</p><p><strong>' .
		esc_html__( 'Need help upgrading? Ask your web host!', 'easy-digital-downloads' ) .
	'</strong><br />' .
	wp_kses(
		sprintf(
			/* translators: %1$s Opening anchor tag, do not translate. %2$s Closing anchor tag, do not translate. */
			__(
				'Many web hosts can give you instructions on how/where to upgrade your version of PHP through their control panel, or may even be able to do it for you. If you need to change hosts, please see %1$sour hosting recommendations%2$s.',
				'easy-digital-downloads'
			),
			'<a href="https://easydigitaldownloads.com/recommended-wordpress-hosting/" target="_blank" rel="noopener noreferrer">',
			'</a>'
		),
		array(
			'a' => array(
				'href'   => true,
				'target' => true,
				'rel'    => true,
			),
		)
	) . '</p></div>';

	return $html;
}
add_filter( 'edd_after_setting_output', 'edds_payment_gateways_notice', 10, 2 );
